動画：ナイジェリアで少女らによる自爆攻撃、ロケット弾も撃ち込まれ31人死亡 写真1枚 国際ニュース：AFPBB News
Description: 【6月18日 AFP】ナイジェリア北東部ボルノ（Borno）州で16日夜、イスラム過激派組織「ボコ・ハラム（Boko Haram）」によるものと思われる少女を使った自爆攻撃が起き、31人が死亡した。

ニュース 戦争・紛争 Video

# 動画：ナイジェリアで少女らによる自爆攻撃、ロケット弾も撃ち込まれ31人死亡

2018年6月18日 10:01発信地：カノ/ナイジェリア [ ナイジェリア アフリカ ]

## このニュースをシェア

【6月18日 AFP】ナイジェリア北東部ボルノ（Borno）州で16日夜、イスラム過激派組織「ボコ・ハラム（Boko Haram）」によるものと思われる少女を使った自爆攻撃が起き、31人が死亡した。地元当局者と民兵指導者が17日、AFPに明らかにした。

攻撃はボルノ州の町ダンボア（Damboa）で、イスラム教の断食月「ラマダン（Ramadan）」明けの祭り「イード・アル・フィトル（Eid al-Fitr）」の祝いから帰る途中の人々を狙って起きたもので、ボコ・ハラムの犯行と思われる特徴があった。

数回の自爆の後、襲撃者らは自爆攻撃の現場に集まった群集の中に携行式ロケット弾を撃ち込み、死傷者がさらに増えた。

地元の民兵指導者は「昨夜ダンボアで2度の自爆攻撃とロケット弾による爆発があり、31人が死亡した。その他に数人が負傷した」と語り、ボコ・ハラムの犯行であることは明らかだと述べた。

地元当局者は「死傷者の大半は町の外から発射されたロケット弾によるものだった。事件後に、自爆攻撃が6人の少女によって実行されたことが明らかになった。救急隊が現場で6人の頭部を発見した。顔つきからして7歳から10歳までの少女だった」と述べた。

政府はボコ・ハラムが劣勢にあると繰り返し主張しているが、あるアナリストは「ボコ・ハラムはナイジェリア北東部で大量の死傷者を出す攻撃を行う意図と作戦能力を維持している」と指摘している。(c)AFP/Aminu ABUBAKAR

戦争・紛争 一覧へ>
メディア・報道関係・法人の方向け 写真・動画 購入のお問合せ>
PR :
PR :

## あわせて読みたい

## Top story

- ### 金正恩氏が訪中、習国家主席と会談 中国国営メディアが報道

- ### 「大統領と呼ぶように」マクロン氏、愛称で声掛けた中学生にお説教

- ### 日本がコロンビアから金星、アジア勢はW杯史上初めて南米チ―ムに勝利

- ### 【AFP記者コラム】地中海で「やつらをぶちのめせ」

- ### 【特集】AFPのベストショット：5月26日～6月1日

## Special PR

- ### 「時事トレンド」に注目！グローバルな視点で世界を見渡してみよう

- ### 特集：北朝鮮情勢緊張高まる北朝鮮情勢、世界から届いた最新情報と解説

- ### 採用情報『AFPBB News』を運営するスタッフを募集します